/*
 * Slawas.pl Copyright &copy; 2011-2012 
 * http://slawas.pl 
 * All rights reserved.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
 * NO EVENT SHALL SŁAWOMIR CICHY BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.scbpm.integrations;

import java.io.IOException;
import java.sql.SQLException;

import javax.naming.NamingException;

import org.jdom.Element;
import org.scbpm.lib.api.SQLQueryFactory;
import org.scbpm.lib.cache.core.ObjectCacheErrorException;
import org.scbpm.lib.ldap.exceptions.FactoryNewInstanceException;

/**
 * SQLQuery - zbiór metod integracyjnych dotyczących zapytań przechowywanych w
 * pamięci podręcznej.
 * 
 * @author Sławomir Cichy &lt;slawas@slawas.pl&gt;
 * @version $Revision: 1.1 $
 * 
 */
public class SQLQuery {

	public static Object executeSQL(String sql, String dataSourceName,
			String returnType) throws ObjectCacheErrorException,
			FactoryNewInstanceException, Exception {
		return executeSQL(sql, null, dataSourceName, returnType, null);
	}

	public static Object executeSQL(String sql, String dataSourceName,
			Integer maxRecords, String returnType)
			throws ObjectCacheErrorException, FactoryNewInstanceException,
			Exception {
		return executeSQL(sql, maxRecords, dataSourceName, returnType, null);
	}

	public static Object executeSQL(String sql, Integer maxRecords,
			String dataSourceName, String returnType, Long cacheTimeToLive)
			throws ObjectCacheErrorException, FactoryNewInstanceException,
			Exception {
		return SQLQueryFactory
				.getFactory()
				.getNewInstance()
				.executeSQL(sql, maxRecords, dataSourceName, returnType,
						cacheTimeToLive);
	}

	public static Element getCachedQueries(Integer maxRecords)
			throws ObjectCacheErrorException, FactoryNewInstanceException {
		return SQLQueryFactory.getFactory().getNewInstance()
				.getCachedQueries(maxRecords);
	}

	public static void refreshElement(String key)
			throws ObjectCacheErrorException, FactoryNewInstanceException,
			Exception {
		SQLQueryFactory.getFactory().getNewInstance().refreshElement(key);
	}

	public void removeElement(String key) throws ObjectCacheErrorException,
			NamingException, SQLException, IOException,
			FactoryNewInstanceException {
		SQLQueryFactory.getFactory().getNewInstance().removeElement(key);
	}
}
