/*
 * Slawas.pl Copyright &copy; 2011-2012 
 * http://slawas.pl 
 * All rights reserved.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
 * NO EVENT SHALL SŁAWOMIR CICHY BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.scbpm.integrations;

import com.lombardisoftware.core.TeamWorksException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import org.apache.commons.lang.StringUtils;
import org.jdom.Element;
import org.scbpm.lib.api.UserSynchronizationFactory;
import org.scbpm.lib.ldap.exceptions.FactoryNewInstanceException;
import org.scbpm.lib.ldap.provider.ProviderOptions;

/**
 * UserSynchronization - zbiór metod integracyjnych dotyczących synchronizacji
 * danych użytkowników.
 * 
 * @author Sławomir Cichy &lt;slawas@slawas.pl&gt;
 * @version $Revision: 1.1 $
 * 
 */
public class UserSynchronization {

	public UserSynchronization() {
	}

	/**
	 * Synchronizacja listy użytkowników. Domyślnie aktualizacja powiązanych
	 * grup oraz synchronizację pomimo istnienia aktualnego wpisu. Metoda nie
	 * będzie próbować dodawać nowych użytkowników do bazy danych IBM BPM.
	 * 
	 * @param ldapOptions
	 *            XML konfiguracyjny w postaci łańcucha znakowego.
	 * @param organizationalUnitNames
	 *            lista nazw jednostek organizacyjnych odseparowanych znakiem
	 *            przecinka (może być pusta, czyli {@code null}), wtedy będzie
	 *            korzystać z domyślnych ctxDN zdefiniowanych w
	 *            {@link ProviderOptions#getBaseCtxDN()} oraz
	 *            {@link ProviderOptions#getRolesCtxDN()}.
	 * @param users
	 *            lista nazw użytkowników odseparowanych znakiem ''
	 * @return lista komunikatów związanych przebiegiem synchronizacji
	 *         użytkowników.
	 * @throws TeamWorksException
	 */
	public static Element syncUsers(String ldapOptions,
			String organizationalUnitNames, String usersList)
			throws FactoryNewInstanceException, TeamWorksException, IOException {
		return syncUsers(ldapOptions, organizationalUnitNames, usersList, true,
				true, true, false);
	}

	/**
	 * Synchronizacja listy użytkowników.
	 * 
	 * @param ldapOptions
	 *            XML konfiguracyjny w postaci łańcucha znakowego.
	 * @param organizationalUnitNames
	 *            lista nazw jednostek organizacyjnych odseparowanych znakiem
	 *            przecinka (może być pusta, czyli {@code null}), wtedy będzie
	 *            korzystać z domyślnych ctxDN zdefiniowanych w
	 *            {@link ProviderOptions#getBaseCtxDN()} oraz
	 *            {@link ProviderOptions#getRolesCtxDN()}.
	 * @param users
	 *            lista użytkowników
	 * @param updateWithGroupMembership
	 *            czy aktualizować z powiązaniami do grup
	 * @param force
	 *            czy wykonać synchronizację użytkownika pomimo istnienia
	 *            aktualnego wpisu w {@link #syncInfoCache}
	 * @param useDefaultParams
	 *            czy nadpisać ustawienia użytkownika ustawieniami domyślnymi?
	 *            Dotyczy tylko parametru
	 *            {@link ProviderOptions#getDefaultTaskNotification()}.
	 * @param tryAddNewUser
	 *            czy próbować dodawać nowych użytkowników nie istniejących w
	 *            systemie IBM BPMS.
	 * @return lista komunikatów związanych przebiegiem synchronizacji
	 *         użytkowników.
	 * @throws FactoryNewInstanceException
	 * @throws TeamWorksException
	 */
	public static Element syncUsers(String ldapOptions,
			String organizationalUnitNames, String usersList,
			boolean updateWithGroupMembership, boolean force,
			boolean useDefaultParams, boolean tryAddNewUser)
			throws FactoryNewInstanceException, TeamWorksException, IOException {
		ProviderOptions po = ProviderOptions.getNewInstance(ldapOptions);
		org.scbpm.lib.security.UserSynchronization usf = UserSynchronizationFactory
				.getFactory().getNewInstance(po);
		List<String> list = null;
		if (StringUtils.isNotBlank(usersList) && !"*".equals(usersList)) {
			String users[] = usersList.split(",");
			list = new ArrayList<String>();
			for (int i = 0; i < users.length; i++)
				list.add(StringUtils.trim(users[i]));

		}
		String organizationalUnitArray[] = null;
		if (StringUtils.isBlank(organizationalUnitNames)) {
			organizationalUnitArray = new String[1];
		} else {
			organizationalUnitArray = organizationalUnitNames.split("\\,");
			for (int i = 0; i < organizationalUnitArray.length; i++)
				organizationalUnitArray[i] = StringUtils
						.trim(organizationalUnitArray[i]);

		}
		return usf.syncUsers(organizationalUnitArray, list,
				updateWithGroupMembership, force, useDefaultParams,
				tryAddNewUser);
	}
}
